@@ -44,8 +44,6 @@
  */
 int
 ipmi_sensors_oem_inventec_output_oem_record (ipmi_sensors_state_data_t *state_data,
-					     const void *sdr_record,
-					     unsigned int sdr_record_len,
 					     uint32_t oem_record_manufacturer_id,
 					     const uint8_t *oem_data,
 					     unsigned int oem_data_len)
@@ -53,8 +51,6 @@ ipmi_sensors_oem_inventec_output_oem_record (ipmi_sensors_state_data_t *state_da
   int ret;
 
   assert (state_data);
-  assert (sdr_record);
-  assert (sdr_record_len);
   assert (oem_data);
   assert (oem_data_len);
   assert (state_data->prog_data->args->verbose_count >= 2);
@@ -68,9 +64,7 @@ ipmi_sensors_oem_inventec_output_oem_record (ipmi_sensors_state_data_t *state_da
   if (state_data->oem_data.product_id == IPMI_INVENTEC_PRODUCT_ID_5441
       || state_data->oem_data.product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
     {
-      if ((ret = ipmi_sensors_oem_intel_node_manager_output_oem_record (state_data,
-									sdr_record,
-									sdr_record_len)) < 0)
+      if ((ret = ipmi_sensors_oem_intel_node_manager_output_oem_record (state_data)) < 0)
 	return (-1);
 
       if (ret)
