@@ -49,8 +49,8 @@
  *  with Ipmiconsole.  If not, see <http://www.gnu.org/licenses/>.
 \*****************************************************************************/
 
-#ifndef _IPMIPOWER_ERROR_H
-#define _IPMIPOWER_ERROR_H
+#ifndef IPMIPOWER_ERROR_H
+#define IPMIPOWER_ERROR_H
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -68,7 +68,7 @@
     char __err[IPMIPOWER_ERROR_BUFLEN];                                         \
     int __len = 0;                                                              \
     memset (__err, '\0', IPMIPOWER_ERROR_BUFLEN);                               \
-    if (cmd_args.common.debug)                                                  \
+    if (cmd_args.common_args.debug)                                             \
       __len = snprintf (__err,                                                  \
                         IPMIPOWER_ERROR_BUFLEN,                                 \
                         "(%s, %s, %d): ",                                       \
@@ -91,7 +91,7 @@
   do {                                                                          \
     char __err[IPMIPOWER_ERROR_BUFLEN];                                         \
     int __len = 0;                                                              \
-    if (cmd_args.common.debug)                                                  \
+    if (cmd_args.common_args.debug)                                             \
       {                                                                         \
         memset (__err, '\0', IPMIPOWER_ERROR_BUFLEN);                           \
         __len = snprintf (__err,                                                \
@@ -121,4 +121,4 @@ void ipmipower_debug (const char *fmt, ...);
 
 char * __error_msg_create (const char *fmt, ...);
 
-#endif /* _IPMIPOWER_ERROR_H */
+#endif /* IPMIPOWER_ERROR_H */
