@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_PRODUCT_ID_SPEC_H
-#define _IPMI_PRODUCT_ID_SPEC_H
+#ifndef IPMI_PRODUCT_ID_SPEC_H
+#define IPMI_PRODUCT_ID_SPEC_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -31,11 +31,12 @@ extern "C" {
  * I'm not sure.  At minimum, it covers the 2900, 2950, R610, and
  * R710.
  */
-#define __IPMI_DELL_PRODUCT_ID_POWEREDGE    256
-#define IPMI_DELL_PRODUCT_ID_POWEREDGE_2900 __IPMI_DELL_PRODUCT_ID_POWEREDGE
-#define IPMI_DELL_PRODUCT_ID_POWEREDGE_2950 __IPMI_DELL_PRODUCT_ID_POWEREDGE
-#define IPMI_DELL_PRODUCT_ID_POWEREDGE_R610 __IPMI_DELL_PRODUCT_ID_POWEREDGE
-#define IPMI_DELL_PRODUCT_ID_POWEREDGE_R710 __IPMI_DELL_PRODUCT_ID_POWEREDGE
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_BASE 256
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_2900 IPMI_DELL_PRODUCT_ID_POWEREDGE_BASE
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_2950 IPMI_DELL_PRODUCT_ID_POWEREDGE_BASE
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_R610 IPMI_DELL_PRODUCT_ID_POWEREDGE_BASE
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_R710 IPMI_DELL_PRODUCT_ID_POWEREDGE_BASE
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_R720 IPMI_DELL_PRODUCT_ID_POWEREDGE_BASE
 
 /* achu: 0 doesn't seem right?  Did the manufacturer not burn the
  * right ID in?
@@ -193,29 +194,29 @@ extern "C" {
 
 /* Seen in the wild w/ Peppercon IANA number 10437 */
 /* achu: there is no product name pattern here, what gives Supermicro? */
-#define __IPMI_SUPERMICRO_PRODUCT_ID_FOUR      4
-#define IPMI_SUPERMICRO_PRODUCT_ID_X7DBR_3     __IPMI_SUPERMICRO_PRODUCT_ID_FOUR
-#define IPMI_SUPERMICRO_PRODUCT_ID_X7DB8       __IPMI_SUPERMICRO_PRODUCT_ID_FOUR
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTN       __IPMI_SUPERMICRO_PRODUCT_ID_FOUR
-#define IPMI_SUPERMICRO_PRODUCT_ID_X7SBI_LN4   __IPMI_SUPERMICRO_PRODUCT_ID_FOUR
+#define IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE   4
+#define IPMI_SUPERMICRO_PRODUCT_ID_X7DBR_3     IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X7DB8       IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTN       IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X7SBI_LN4   IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE
 
 /* Seen in the wild w/ Supermicro workaround IANA number 47488 */
-#define __IPMI_SUPERMICRO_PRODUCT_ID_X8DT      43707
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTH       __IPMI_SUPERMICRO_PRODUCT_ID_X8DT
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTG       __IPMI_SUPERMICRO_PRODUCT_ID_X8DT
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTU       __IPMI_SUPERMICRO_PRODUCT_ID_X8DT
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DT3_LN4F  __IPMI_SUPERMICRO_PRODUCT_ID_X8DT
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE   43707
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTH       IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTG       IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTU       IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DT3_LN4F  IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE
 /* achu: X8DTU-6+, why not same as above?  Not sure, possibly created
  * specifically for vendor or vendor changed for themselves.
  */
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTU_6PLUS 1549
-#define __IPMI_SUPERMICRO_PRODUCT_ID_X8DTL     6
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTL       __IPMI_SUPERMICRO_PRODUCT_ID_X8DTL
-#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTL_3F    __IPMI_SUPERMICRO_PRODUCT_ID_X8DTL
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTL_BASE     6
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTL       IPMI_SUPERMICRO_PRODUCT_ID_X8DTL_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X8DTL_3F    IPMI_SUPERMICRO_PRODUCT_ID_X8DTL_BASE
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8SIL_F     1541
-#define __IPMI_SUPERMICRO_PRODUCT_ID_X9SC      1572
-#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCL       __IPMI_SUPERMICRO_PRODUCT_ID_X9SC
-#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCM       __IPMI_SUPERMICRO_PRODUCT_ID_X9SC
+#define IPMI_SUPERMICRO_PRODUCT_ID_X9SC_BASE   1572
+#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCL       IPMI_SUPERMICRO_PRODUCT_ID_X9SC_BASE
+#define IPMI_SUPERMICRO_PRODUCT_ID_X9SCM       IPMI_SUPERMICRO_PRODUCT_ID_X9SC_BASE
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTNPLUS_F 1551
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8SIE       1037
 #define IPMI_SUPERMICRO_PRODUCT_ID_X9SCA_F_O   1585
@@ -228,8 +229,23 @@ extern "C" {
 /* Seen in the wild w/ Magnum Technologies IANA number 5593 */
 /* defined above: IPMI_SUPERMICRO_PRODUCT_ID_X8DTL */
 
+/******************************************* 
+ * Wistron                                 *
+ *******************************************/
+
+/* achu: don't know original product name, so just using C6220. 
+ * Will readjust as needed if learned later. 
+ */
+#define IPMI_WISTRON_PRODUCT_ID_C6220          131
+
+/* 
+ * Wistron derived
+ */
+
+#define IPMI_DELL_PRODUCT_ID_POWEREDGE_C6220   IPMI_WISTRON_PRODUCT_ID_C6220
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif
+#endif /* IPMI_PRODUCT_ID_SPEC_H */
