@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_LAN_CMDS_TEMPLATES_H
-#define _IPMI_LAN_CMDS_TEMPLATES_H
+#ifndef IPMI_LAN_CMDS_TEMPLATES_H
+#define IPMI_LAN_CMDS_TEMPLATES_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -812,4 +812,4 @@ FIID Template: tmpl_cmd_get_ip_udp_rmcp_statistics_rs
 }
 #endif
 
-#endif  /* _IPMI_LAN_CMDS_TEMPLATES_H */
+#endif /* IPMI_LAN_CMDS_TEMPLATES_H */
